#############
# $Id: mpsa_to_irods_migration_helper.pm 12818 2011-03-16 12:53:22Z ajb $
# Created By: Marina Gourtovaia mg8@sanger.ac.uk
# Last Maintained By: $Author: ajb $
# Created On: 18 November 2010
# Last Changed On: $Date: 2011-03-16 12:53:22 +0000 (Wed, 16 Mar 2011) $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-pipeline/tags/release-26.1/lib/npg_pipeline/archive/mpsa_to_irods_migration_helper.pm $

package npg_pipeline::archive::mpsa_to_irods_migration_helper;

use Moose;
use Carp;
use English qw{-no_match_vars};
use File::Spec::Functions qw/catfile/;

use Readonly; Readonly::Scalar our $VERSION => do { my ($r) = q$LastChangedRevision: 12818 $ =~ /(\d+)/mxs; $r; };

extends q{npg_pipeline::archive};

Readonly::Scalar our $LAST => -1;

=head1 NAME

npg_pipeline::archive::mpsa_to_irods_migration_helper

=head1 VERSION

$LastChangedRevision: 12818 $

=head1 SYNOPSIS

=head1 DESCRIPTION

Submits all sorts of scripts as bjobs.


=head1 SUBROUTINES/METHODS

=head2 script_command

=cut

sub script_command {
    my ($self, $function_name) = @_;

    if (!$self->external_script_names_conf->{$function_name}) {
        croak qq[No script for function $function_name];
    }

    my $command = join q[ ], $self->external_script_names_conf->{$function_name}, q[--id_run], $self->id_run;
    foreach my $lane ($self->positions) {
        $command .= qq[ --lanes $lane];
    }
    $command .= q[ --archive_path ]      . $self->archive_path;
    $command .= q[ --bustard_path ]      . $self->bustard_path;
    $command .= q[ --runfolder_path ]    . $self->runfolder_path;
    $command .= q[ --recalibrated_path ] . $self->archive_path;
    $command .= q[ --conf_path ]         . $self->conf_path;
    $command .= q[ --nois_indexed];
    return $command;
}

=head2 bsub_prefix

=cut

sub bsub_prefix {
    my ($self, $function_name, $arg_refs) = @_;
    ## no critic (CodeLayout::ProhibitParensWithBuiltins)
    my $job_name = join(q[_] , $function_name, $self->id_run, join(q[], $self->positions));
    my $bsub_out = join(q[_], $job_name, $self->timestamp, q[%J]) . q[.out];
    my $bsub = q[bsub] .
               q[ -q ] . $self->lsf_queue() .
               q[ -J ] . $job_name .
               q[ -o ] . catfile($self->make_log_dir($self->archive_path), $bsub_out) .
               q[ ]    . $self->fs_resource_string( {counter_slots_per_job => 1,} );
    if ($arg_refs->{required_job_completion}) {
        $bsub .= q[ ] . $arg_refs->{required_job_completion};
    }
    return $bsub;
}

=head2 bsub_command

=cut

sub bsub_command {
    my ($self, $function_name, $arg_refs) = @_;

    return join q[ ], $self->bsub_prefix($function_name, $arg_refs),
                      q['] . $self->script_command($function_name) . q['];
}

=head2 launch_bsub_job

=cut

sub launch_bsub_job {
    my ($self, $arg_refs) = @_;

    my ($package, $filename, $line, $calling_subr, $has_args, $wantarray )= caller(1);  ## no critic (CodeLayout::ProhibitParensWithBuiltins)
    if (!$calling_subr) {
        ($package, $filename, $line, $calling_subr, $has_args, $wantarray )= caller(0);  ## no critic (CodeLayout::ProhibitParensWithBuiltins)
        croak qq[Calling function not defined in $calling_subr];
    }
    my @names = split /:/xms, $calling_subr;
    $calling_subr = $names[$LAST];

    if ($calling_subr eq q[qc_db_delete_autoqc] ||
            $calling_subr eq q[populate_archive_directory_from_mpsa]) {
        if ($self->no_lanes) {
            croak qq[Pipeline function $calling_subr: --lanes option should be set explicitly];
        }
    }
    return ($self->submit_bsub_command($self->bsub_command($calling_subr, $arg_refs)));
}

no Moose;
__PACKAGE__->meta->make_immutable;
1;
__END__

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

=over

=item Moose

=item Carp

=item English -no_match_vars

=item Readonly

=item npg_pipeline::archive

=back

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 AUTHOR

$Author: ajb $

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2010 GRL, by Marina Gourtovaia (mg8@sanger.ac.uk)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
