#############
# $Id: bustard.pm 12818 2011-03-16 12:53:22Z ajb $
# Created By: ajb
# Last Maintained By: $Author: ajb $
# Created On: 2009-10-22
# Last Changed On: $Date: 2011-03-16 12:53:22 +0000 (Wed, 16 Mar 2011) $
# $HeadURL: svn+ssh://svn.internal.sanger.ac.uk/repos/svn/new-pipeline-dev/npg-pipeline/tags/release-26.1/lib/npg_pipeline/pluggable/harold/bustard.pm $

package npg_pipeline::pluggable::harold::bustard;
use Moose;
use MooseX::InsideOut;
use Carp;
use English qw{-no_match_vars};
use Readonly; Readonly::Scalar our $VERSION => do { my ($r) = q$LastChangedRevision: 12818 $ =~ /(\d+)/mxs; $r; };

extends qw{npg_pipeline::pluggable::harold};
with q{npg_common::roles::run::fs_resource};
with q{npg_pipeline::roles::business::bustard_lsf_reqs};

=head1 NAME

npg_pipeline::pluggable::harold::bustard

=head1 VERSION

$LastChangedRevision: 12818 $

=head1 SYNOPSIS

  my $oHaroldBustard = npg_pipeline::pluggable::harold::bustard->new({
    run_folder => $sRunFolder,
  })

=head1 DESCRIPTION

pluggable module runner for the bustard pipeline

=head1 SUBROUTINES/METHODS

=head2 check_and_fix_cif_files

checks to see if there are broken cif files, and if so, will fix if the fix_broken_files flag is set, else will croak
Should not be submitted as a job at this time.

=cut

sub check_and_fix_cif_files {
  my ( $self, @args ) = @_;

  my $checker = $self->new_with_cloned_attributes( q{npg_pipeline::analysis::CheckCifDif} );

  eval {
    $checker->check_and_fix_cif_files();
    1;
  } or do {
    croak q{Broken files: } . $EVAL_ERROR;
  };

  return ();
}

=head2 run_launch_pb_cal

Submit a job which will launch all the PB_cal calibration pipeline. This deliberately return no job_ids.

=cut

sub run_launch_pb_cal {
  my ($self, $method, @args) = @_;

  my $required_job_completion = shift @args;

  if ( $self->no_pb_cal() ) {
    $self->log( q{pb_cal turned off by user request flag} );
    return ();
  }

  my $harold = $self->new_with_cloned_attributes(q{npg_pipeline::analysis::harold_calibration});

  $harold->launch_pb_cal({
    required_job_completion => $required_job_completion,
  });

  return ();
}

=head2 make_multiplex_lane_specific_tag_files

This doesn't need to be submitted as a bsub job at this time.
It will create lane specific tag files, so that these can be used for index determination in preference
to a default containing all tags (unless a tag file has been provided, in which case, that will be used)

=cut

sub make_multiplex_lane_specific_tag_files {
  my ($self, @args) = @_;

  my $o_create_lane_tag_file = $self->new_with_cloned_attributes(q{npg_pipeline::analysis::create_lane_tag_file});

  eval {
    $o_create_lane_tag_file->generate();
    1;
  } or do {
    croak q{Problem creating lane specific tag file: } . $EVAL_ERROR;
  };

  return ();
}

=head2 run_bustard

run Bustard and Gerald setup steps (not including the makes) - Returns an array

=cut

sub run_bustard {

  my ($self, @args) = @_;
  my $required_job_completion = shift @args;

#  require npg_pipeline::analysis::bustard;

  my $bustard = $self->new_with_cloned_attributes(q{npg_pipeline::analysis::bustard});

  my @job_ids = $bustard->submit_bustard({
    required_job_completion => $required_job_completion,
  });

  return @job_ids;

}

# Generic logic for invoking bustard.pm 'make' actions
sub _make_something {

  my ($self, $what, @args) = @_;
  my $required_job_completion = shift @args;

  my $bustard = $self->new_with_cloned_attributes(q{npg_pipeline::analysis::bustard});
  my @job_ids = $bustard->$what({
    required_job_completion => $required_job_completion,
  });

  return @job_ids;

}

=head2 make_bustard_matrix_lanes
=head2 make_bustard_matrix_all
=head2 make_bustard_phasing_lanes
=head2 make_bustard_phasing_all
=head2 make_bustard_basecalls_lanes
=head2 make_bustard_basecalls_all
=head2 make_gerald_tiles
=head2 make_gerald_qtable
=head2 make_gerald_lanes
=head2 make_gerald_all

Submit Bustard & Gerald make jobs in dependency order

=cut

sub make_bustard_matrix_lanes {
  my ($self, @args) = @_;
  return $self->_make_something('make_bustard_matrix_lanes', @args);
}

sub make_bustard_matrix_all {
  my ($self, @args) = @_;
  return $self->_make_something('make_bustard_matrix_all', @args);
}

sub make_bustard_phasing_lanes {
  my ($self, @args) = @_;
  return $self->_make_something('make_bustard_phasing_lanes', @args);
}

sub make_bustard_phasing_all {
  my ($self, @args) = @_;
  return $self->_make_something('make_bustard_phasing_all', @args);
}

sub make_bustard_basecalls_lanes {
  my ($self, @args) = @_;
  return $self->_make_something('make_bustard_basecalls_lanes', @args);
}

sub make_bustard_basecalls_all {
  my ($self, @args) = @_;
  return $self->_make_something('make_bustard_basecalls_all', @args);
}

sub make_gerald_tiles {
  my ($self, @args) = @_;
  return $self->_make_something('make_gerald_tiles', @args);
}

sub make_gerald_qtable {
  my ($self, @args) = @_;
  return $self->_make_something('make_gerald_qtable', @args);
}

sub make_gerald_lanes {
  my ($self, @args) = @_;
  return $self->_make_something('make_gerald_lanes', @args);
}

sub make_gerald_all {
  my ($self, @args) = @_;
  return $self->_make_something('make_gerald_all', @args);
}

=head2 run_cleanup

Submit the cleanup equivalent, which acts on files and produces the archival files and does internal qc (post_qseq)

=cut

sub run_cleanup {

  my ($self, @args) = @_;

  # check to see if cleanup/post_qseq is has been turned off
  if ($self->no_post_qseq()) {
    $self->log(q{Post_QSEQ (cleanup/archival file creation) turned off});
    return ();
  }

  my $required_job_completion = shift @args;

  my $bustard = $self->new_with_cloned_attributes(q{npg_pipeline::analysis::bustard});

  my @job_ids = $bustard->submit_cleanup({
    required_job_completion => $required_job_completion,
  });

  return @job_ids;

}

=head2 demultiplex

If the run is indexed/multiplexed, then sort files out to ensure that GERALD (for 1.6) can cope.

=cut

sub demultiplex {
  my ($self, @args) = @_;

  my $required_job_completion = shift @args;
  my $multiplex = $self->new_with_cloned_attributes(q{npg_pipeline::analysis::multiplex});

  my @job_ids = $multiplex->submit_index_decoder_jobs({
    required_job_completion => $required_job_completion,
  });

  return @job_ids;
}

sub _default_function_order {
  my ($self) = @_;
  return $self->function_order_conf()->{bustard};
}

no Moose;
__PACKAGE__->meta->make_immutable;
1;
__END__

=head1 DIAGNOSTICS

=head1 CONFIGURATION AND ENVIRONMENT

=head1 DEPENDENCIES

=over

=item Moose

=item MooseX::InsideOut

=item Carp

=item English -no_match_vars

=item Readonly

=back

=head1 INCOMPATIBILITIES

=head1 BUGS AND LIMITATIONS

=head1 AUTHOR

$Author: ajb $

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2010 GRL, by Andy Brown (ajb@sanger.ac.uk)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
