# $Id: 10-pluggable_harold_bustard.t 12818 2011-03-16 12:53:22Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 9;
use Test::Exception;
use lib qw{t};
use t::util;
use File::Slurp;

my $util = t::util->new();
$util->catch_email();

$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();
$ENV{TEST_FS_RESOURCE} = q{nfs_12};

BEGIN {
  use_ok(q{npg_pipeline::pluggable::harold::bustard});
}

my $runfolder_path = $util->analysis_runfolder_path();
$ENV{TEST_USERAGENT} = $runfolder_path . q{/useragent};

{
  $util->set_staging_analysis_area();
  my $bustard_pipeline;
  lives_ok {
    $bustard_pipeline = npg_pipeline::pluggable::harold::bustard->new({
      schema => q{bustard},
      script_name => q{test},
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
    });
  } q{no croak creating new object};
  isa_ok($bustard_pipeline, q{npg_pipeline::pluggable::harold::bustard}, q{$bustard_pipeline});


#  lives_ok {
#    $bustard_pipeline->main();
#  } q{no croak processing through default bustard order};
}

{
  $util->set_staging_analysis_area();
  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );
  my $bustard_path = $util->standard_analysis_bustard_path();
  qx{rm -rf $bustard_path};

  my $bustard_pipeline;
  lives_ok {
    $bustard_pipeline = npg_pipeline::pluggable::harold::bustard->new({
      schema => q{bustard},
      script_name => q{test},
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20101007-150059},
      verbose => 1,
      no_spider => 1,
    });
  } q{no croak creating new object};

  my $archive_path = q{ap - nothing};
  my $bustard_path = q{bp - nothing};
  eval {
    $archive_path = $bustard_pipeline->archive_path();
  } or do {};
  eval {
    $bustard_path = $bustard_pipeline->bustard_path();
  } or do {};

  is( $archive_path, q{ap - nothing}, q{archive path not worked out - does not exist} );
  is( $bustard_path, q{bp - nothing}, q{bustard path not worked out - does not exist} );
  lives_ok {
    $bustard_pipeline->spider();
  } q{spider ok};
  is( $util->drop_temp_part_from_paths( $ENV{ npg_common::request->cache_dir_var_name() } ), q{/staging/IL2/analysis/123456_IL2_1234/cache_webservice_analysis_20101007-150059}, q{correct cache dir obtained in environment variable} );

  ok( !$bustard_pipeline->has_bustard_path(), q{no bustard_path} );

}

1;