# $Id: 20-archive_file_generation-fastqcheck.t 12818 2011-03-16 12:53:22Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 16;
use lib qw{t};
use t::util;
use Test::Exception;

use_ok('npg_pipeline::archive::file::generation::fastqcheck');

my $util = t::util->new();
my $conf_path = $util->conf_path();

$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();

$ENV{TEST_API_UTIL} = $util->apiutil();

{

  my $fastqcheck_generator = npg_pipeline::archive::file::generation::fastqcheck->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
  });
  isa_ok($fastqcheck_generator, q{npg_pipeline::archive::file::generation::fastqcheck}, q{$fastqcheck_generator});

  my $arg_refs = {};
  $arg_refs->{required_job_completion}  = q{-w'done(123) && done(321)'};

  $util->create_analysis();
  my @jids;
  eval { @jids = $fastqcheck_generator->generate($arg_refs); };
  is($EVAL_ERROR, q{}, q{no croak running generate});
  is(scalar@jids, 1, q{1 job id returned});

  my $bsub_command = $util->drop_temp_part_from_paths( $fastqcheck_generator->_generate_bsub_command( $arg_refs ) );
  my $expected_command = q{bsub -q test -R 'rusage[nfs_12=1]' -w'done(123) && done(321)' -J fastqcheck_creation_1234_20090709-123456[1-8] -o /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/log/fastqcheck_creation_1234_20090709-123456.%I.%J.out 't/bin/software/solexa/bin/fqcheck_creator < /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_`echo $LSB_JOBINDEX`.fastq > /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_`echo $LSB_JOBINDEX`.fastqcheck'};

  is( $bsub_command, $expected_command, q{generated bsub command is correct} );
}
{

  my $fastqcheck_generator = npg_pipeline::archive::file::generation::fastqcheck->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    lane => 4,
    verbose => 0,
    conf_path => $conf_path,
    domain => q{test},
  });
  isa_ok($fastqcheck_generator, q{npg_pipeline::archive::file::generation::fastqcheck}, q{$fastqcheck_generator});

  my $arg_refs = {
    required_job_completion => q{-w'done(123) && done(321)'}
  };

  $util->create_analysis();

  my @jids;
  eval { @jids = $fastqcheck_generator->generate($arg_refs); };
  is($EVAL_ERROR, q{}, q{no croak running generate});
  is(scalar@jids, 1, q{1 job id returned});

  my $bsub_command = $util->drop_temp_part_from_paths( $fastqcheck_generator->_generate_bsub_command( $arg_refs ) );
  my $expected_command = q{bsub -q test -R 'rusage[nfs_12=1]' -w'done(123) && done(321)' -J fastqcheck_creation_1234_20090709-123456[4] -o /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/log/fastqcheck_creation_1234_20090709-123456.%I.%J.out 't/bin/software/solexa/bin/fqcheck_creator < /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_`echo $LSB_JOBINDEX`.fastq > /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_`echo $LSB_JOBINDEX`.fastqcheck'};

  is( $bsub_command, $expected_command, q{generated bsub command is correct} );
}
{ 
  $ENV{TEST_RUN_OBJECT} = npg::api::run->new({
    util => $util->apiutil(),
    id_run => 1234,
  });

  $util->create_multiplex_analysis();

  my $generator;

  lives_ok { $generator = npg_pipeline::archive::file::generation::fastqcheck->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
  }); } q{no croak creating $fastq_generator object};
  isa_ok($generator, q{npg_pipeline::archive::file::generation::fastqcheck}, q{$generator});

  my $arg_refs = {
    required_job_completion => q{-w'done(123) && done(321)'}
  };

  my @jids;
  eval { @jids = $generator->generate( $arg_refs ); };
  is($EVAL_ERROR, q{}, q{no croak running generate});
  is(scalar@jids, 3, q{2 job ids returned});
  
  $arg_refs = {
    position => 1,
    file_name => '/tmp/1234_1_1.fastq',
    output_dir => '/tmp',
    array_string => q{[1001-1004,8000-8012]},
    required_job_completion => q{-w'done(123) && done(321)'},
  };

  my $bsub_command = $util->drop_temp_part_from_paths( $generator->_generate_bsub_command( $arg_refs ) );
  my $expected_command = q{bsub -q test -R 'rusage[nfs_12=1]' -w'done(123) && done(321)' -J fastqcheck_creation_1234_1.fastq_20090709-123456[1001-1004,8000-8012] -o /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/log/fastqcheck_creation_1234_1.fastq_20090709-123456.%I.%J.out 't/bin/software/solexa/bin/fqcheck_creator < /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_/tmp/1234_1_1.fastq.fastq > /staging/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/1234_/tmp/1234_1_1.fastq.fastqcheck'};

  is( $bsub_command, $expected_command, q{generated bsub command is correct} );

  $ENV{TEST_API_UTIL} = $util->apiutil();

  my $runfolder = $generator->runfolder_path();
  `cp t/data/tag_files/lane_7.tag $runfolder`; 

  my $dir = $generator->archive_path();
  mkdir "$dir/lane7";

  $arg_refs->{fastqcheck_by_tag} = 1;

  my @jids;
  lives_ok { @jids = $generator->generate($arg_refs); } q{no croak running generate};
 
  is(scalar@jids, 2, q{2 jobs ids returned for creating fastqcheck by tag for lane 7});

  `rm fi`;
}

1;
