# $Id: 25-analysis-bustard.t 12818 2011-03-16 12:53:22Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 27;
use Test::Exception;
use lib qw{t};
use t::util;
use npg::api::run;
use File::Slurp;


my $util = t::util->new();
$util->catch_email();

$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();
my $tmp_dir = $util->temp_directory();
$ENV{TEST_FS_RESOURCE} = q{nfs_12};

my $conf_path = $util->conf_path();

BEGIN {
  use_ok(q{npg_pipeline::analysis::bustard});
}

my $runfolder_path = $util->analysis_runfolder_path();
my $bustard_home   = qq{$runfolder_path/Data/Intensities};
my $bustard_rta    = qq{$bustard_home/Bustard_RTA};
my $gerald_rta     = qq{$bustard_rta/GERALD_RTA};
my $config_path    = qq{$runfolder_path/Config};

$ENV{TEST_USERAGENT} = $runfolder_path . q{/useragent};

sub set_staging_analysis_area {
  `rm -rf $tmp_dir/staging`;
  `mkdir -p $bustard_home`;
  `mkdir $config_path`;
  `cp t/data/Recipes/Recipe_GA2_37Cycle_PE_v6.1.xml $runfolder_path/`;
  `cp t/data/Recipes/TileLayout.xml $config_path/`;
  return 1;
}

sub add_bustard_and_gerald_dirs {
  `mkdir -p $gerald_rta`;
  return 1;
}

{
  set_staging_analysis_area();
  my $bustard;
  lives_ok {
    $bustard = npg_pipeline::analysis::bustard->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      conf_path => $conf_path,
      domain => q{test},
      no_bsub => 1,
      log_file_path => $runfolder_path,
      log_file_name => q{npg_pipeline_analyse_RTA_20091028-101635.log},
      matrix => q{/a/path/to/some.matrix},
      phasing => q{0.0041},
      prephasing => q{0.0037},
    });
  } q{no croak creating new object};
  isa_ok($bustard, q{npg_pipeline::analysis::bustard}, q{$bustard});

  my $req_job_completion = q{-w'done(123) && done(321)'};
  my $arg_refs = {
    required_job_completion => $req_job_completion,
  };

  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );

  my $fs_resource;
  lives_ok { $fs_resource = $bustard->fs_resource(); } q{fs_resource obtained ok};
  is($fs_resource, q{nfs_12}, q{fs_resource ok});
  is($bustard->runfolder_path(), $runfolder_path, q{runfolder_path ok});

  is($bustard->_pick_control_lane(), 4, q{});
  lives_ok { $bustard->_check_runfolder(); } q{_check_runfolder is ok};
  lives_ok { $bustard->_gerald_config(); } q{_gerald_config is ok};
  add_bustard_and_gerald_dirs();
  is($bustard->find_bustard(), $bustard_rta, q{bustard_rta found ok});
  is($bustard->_find_gerald(), $gerald_rta,  q{gerald_rta found ok});

  my $cleanup_command = q{bsub -q test -w'done(123) && done(321)' -R 'rusage[nfs_12=1]' -o log/post_qseq_1234_20091028-101635-%J.out  -J post_qseq_1234_20091028-101635 't/bin/software/solexa/bin/npg_pipeline_post_qseq --analyse_rta_log_file /staging/IL2/analysis/123456_IL2_1234/npg_pipeline_analyse_RTA_20091028-101635.log --basecall_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/BaseCalls --bustard_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA --conf_path data/config_files --data_path /staging/IL2/analysis/123456_IL2_1234/Data --domain test --expected_cycle_count 37 --fs_resource nfs_12 --id_run 1234 --intensity_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities --lane_count 8 --lsf_queue test --no_bsub  --pb_cal_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/PB_cal --recalibrated_path /staging/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard_RTA/GERALD_RTA --run_folder 123456_IL2_1234 --runfolder_path /staging/IL2/analysis/123456_IL2_1234 --use_bases Y37'};

  my $generated_cleanp_command = $util->drop_temp_part_from_paths( $bustard->_cleanup_bsub_cmd($arg_refs) );
diag $bustard->is_indexed();
  is($generated_cleanp_command, $cleanup_command, q{generated cleanup command is correct});

  my $basecalls_all_cmd = q{bsub -n 8 -q test -o log/bustard_basecalls_1234_all_20091028-101635.%J.out  -J bustard_basecalls_1234_all_20091028-101635 -C 99999999 -R 'select[mem>13800] rusage[mem=13800,nfs_12=8] span[hosts=1]' -M 13800000 -w'done(123) && done(321)' ' t/bin/software/solexa/bin/make -j 8 all '};

  is($bustard->_bsub_command_string(qw{/test/dir all bustard_basecalls_1234_all}, $req_job_completion),
   $basecalls_all_cmd, q{generated matrix_lanes_command ok}
  );
  
  $arg_refs = {
    directory     => q{/test/dir},
    target        => q{matrix_} . $bustard->lsb_jobindex() . q{_finished.txt},
    tag           => q{bustard_matrix_1234},
    array_string  => q{[1-8]},
    position      => $bustard->lsb_jobindex(),
    depends_on    => $req_job_completion,
  };

  my $matrix_lanes_command = q{bsub -n 8 -q test -o log/bustard_matrix_1234_20091028-101635.%I.%J.out  -J bustard_matrix_1234_20091028-101635[1-8] -C 99999999 -R 'select[mem>13800] rusage[mem=13800,nfs_12=8] span[hosts=1]' -M 13800000 -w'done(123) && done(321)' ' t/bin/software/solexa/bin/make -j 8 matrix_`echo $LSB_JOBINDEX`_finished.txt '};

  is( $bustard->_bsub_command_string( $arg_refs), $matrix_lanes_command, q{generated matrix_lanes_command ok} );
}

# test the value of no_eland

{
  my $bustard = npg_pipeline::analysis::bustard->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      conf_path => $conf_path,
      domain => q{test},
  });
  ok(!$bustard->no_eland(), q{eland will run, since neither no_control_lane or no_eland set on construction});
  $bustard = npg_pipeline::analysis::bustard->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      no_eland => 1,
      conf_path => $conf_path,
      domain => q{test},
  });
  ok(!$bustard->no_eland(), q{eland will still run, since no_control_lane not set on construction});
  $bustard = npg_pipeline::analysis::bustard->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      no_control_lane => 1,
      conf_path => $conf_path,
      domain => q{test},
  });
  ok(!$bustard->no_eland(), q{eland will still run, since no_eland not set on construction});
  $bustard = npg_pipeline::analysis::bustard->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      no_eland => 1,
      no_control_lane => 1,
      conf_path => $conf_path,
      domain => q{test},
  });
  ok($bustard->no_eland(), q{eland will not run, since no_control_lane and no_eland set on construction});
}

# test matrix, phasing and prephasing results

{
  my $bustard = npg_pipeline::analysis::bustard->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      conf_path => $conf_path,
      domain => q{test},
  });
  is( $bustard->matrix_value(), q{lane}, q{matrix with no control lane given} );
  is( $bustard->matrix_value( 5 ), q{auto5}, q{matrix with control lane given} );
  is( $bustard->phasing_value(), q{auto}, q{phasing with no control lane given} );
  is( $bustard->phasing_value( 5 ), q{auto5}, q{phasing with control lane given} );
  $bustard = npg_pipeline::analysis::bustard->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      conf_path => $conf_path,
      domain => q{test},
      phasing => q{0.0041},
      prephasing => q{0.0037},
      matrix => q{/a/path/to/some.matrix},
  });
  is( $bustard->matrix_value(), q{/a/path/to/some.matrix}, q{matrix when user defined} );
  is( $bustard->phasing_value(), q{0.0041}, q{phasing when user defined} );
  ok( $bustard->has_prephasing(), q{prephasing is present when user defined} );
  is( $bustard->prephasing(), q{0.0037}, q{prephasing when user defined} );

  $bustard = npg_pipeline::analysis::bustard->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      conf_path => $conf_path,
      domain => q{test},
      phasing => q{0.0041},
      matrix => q{/a/path/to/some.matrix},
  });
  throws_ok {
    $bustard->phasing_value();
  } qr{User[ ]defined[ ]phasing[ ]given,[ ]but[ ]no[ ]user[ ]defined[ ]prephasing[ ]given}, q{phasing croaks if user defined and no user defined prephasing};

}
1;