# $Id: 25-analysis-create_lane_tag_file.t 12818 2011-03-16 12:53:22Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More 'no_plan';#tests => ;
use Test::Exception::LessClever;
use lib qw{t};
use t::util;
use npg::api::run;
use File::Slurp;

my $util = t::util->new();
$util->catch_email();

$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();
$ENV{TEST_FS_RESOURCE} = q{nfs_12};

my $conf_path = $util->conf_path();

BEGIN {
  use_ok(q{npg_pipeline::analysis::create_lane_tag_file});
}

my $runfolder_path = $util->analysis_runfolder_path();
$ENV{TEST_USERAGENT} = $runfolder_path . q{/useragent};

{
  $util->set_rta_staging_analysis_area();
  my $create_lane;
  lives_ok {
    $create_lane = npg_pipeline::analysis::create_lane_tag_file->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      runfolder_path => $runfolder_path,
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{no croak creating new object};
  isa_ok($create_lane, q{npg_pipeline::analysis::create_lane_tag_file}, q{$create_lane});

  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );

  lives_ok {
    $create_lane->generate();
  } q{no croak running generate()};
}

{

  $util->multiplexed_rta_pre_gerald();
  my $create_lane;
  lives_ok {
    $create_lane = npg_pipeline::analysis::create_lane_tag_file->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      runfolder_path => $runfolder_path,
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{no croak creating new object};

  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );
  $create_lane->run()->batch_id(5378);
  is($create_lane->corrected_tag_part_use_bases(), q{Y76,I7n,y76}, q{corrected_tag_part_use_bases returns expected use_bases string});

  lives_ok {
    $create_lane->generate();
  } q{no croak running generate()};

  my $lane_no_pool_content = q{};
  my $lane_5_pool_content  = qq{ACACAGT 7\nACGAGGT 8\nTCCACTG 9\nAGTCCTA 10\nGAGCACA 11\nTACACCT 12\n};

  my $result_lane_5_pool_content  = read_file ( qq{$runfolder_path/lane_5.tag} );
  my $result_lane_no_pool_content = read_file ( qq{$runfolder_path/lane_4.tag} );

  is($result_lane_no_pool_content, $lane_no_pool_content, q{lane no pool content correct});
  is($result_lane_5_pool_content, $lane_5_pool_content, q{lane 5 pool content correct});

}

{
   my $tag_to_trim = [qw(actgffc aacgffc aacdffcd)];
   is(npg_pipeline::analysis::create_lane_tag_file->_tag_common_suffix_length($tag_to_trim), 0, 'tag no common suffix');
   
   $tag_to_trim = [qw(actgffc aacgffc aacdffc)];
   is(npg_pipeline::analysis::create_lane_tag_file->_tag_common_suffix_length($tag_to_trim), 3, 'tag common suffix length 3');

   $tag_to_trim = [qw(aacdffc aacdffc aacdffc)];
   is(npg_pipeline::analysis::create_lane_tag_file->_tag_common_suffix_length($tag_to_trim), 7, 'all tags are the same'); 
}

{
   my $tag_to_trim = [qw(actgffce aacgffcf aacdffcd)];
   is_deeply(npg_pipeline::analysis::create_lane_tag_file->_trim_tag_common_suffix($tag_to_trim),[qw(actgffce aacgffcf aacdffcd)], 'no common suffix');

   $tag_to_trim = [qw(actgffc aacgffc aacdffcd)];
   throws_ok {npg_pipeline::analysis::create_lane_tag_file->_trim_tag_common_suffix($tag_to_trim)} qr/The given tags are different in length/, 'different length tags';

   $tag_to_trim = [qw(actgffc aacgffc aacdffc)];
   is_deeply(npg_pipeline::analysis::create_lane_tag_file->_trim_tag_common_suffix($tag_to_trim), [qw(actg aacg aacd)], 'common suffix length 3');

   $tag_to_trim = [qw(aacdffc aacdffc aacdffc)];
   throws_ok {npg_pipeline::analysis::create_lane_tag_file->_trim_tag_common_suffix($tag_to_trim)} qr{All tags are the same}, 'all tags are the same'; 
}

{
  my $tag_list = [qw(aaa aaa ccc)];
  throws_ok {
    npg_pipeline::analysis::create_lane_tag_file->_check_tag_uniqueness($tag_list);
  } qr{The given tags after trimming are not unique}, q{tags are not unique - throw error};
}

{  

  $util->multiplexed_rta_pre_gerald();
  my $create_lane;
  lives_ok {
    $create_lane = npg_pipeline::analysis::create_lane_tag_file->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      runfolder_path => $runfolder_path,
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{no croak creating new object};

  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );
  $create_lane->run()->batch_id( 6532 );
  my $tag_list_lane1 = $create_lane->batch->lanes->[0]->tag_list();

  my ($index_list, $tag_seq_list) = $create_lane->_process_tag_list($tag_list_lane1);
  is_deeply($index_list, [1,2,3], 'correct index list');
  is_deeply($tag_seq_list, [qw(TAGCTTG CGATGTT GCCAATG)], 'correct tag list after trimming');
  
  $tag_list_lane1->[0]->index(undef);
  ($index_list, $tag_seq_list) = $create_lane->_process_tag_list($tag_list_lane1);
  is($index_list, undef, 'no index list available');
  is($tag_seq_list, undef, 'no expected tag sequence available');
  
  $tag_list_lane1->[0]->expected_sequence(undef);
  ($index_list, $tag_seq_list) = $create_lane->_process_tag_list($tag_list_lane1);
  is($tag_seq_list, undef, 'no expected tag sequence available');
  
  $tag_list_lane1->[0]->index(1);
  $tag_list_lane1->[0]->expected_sequence('TAGCTTGT');
  ($index_list, $tag_seq_list) = $create_lane->_process_tag_list($tag_list_lane1);
  is_deeply($create_lane->_check_tag_length($tag_seq_list),[qw(TAGCTTG CGATGTT GCCAATG)], 'expected tag sequence length are the same as the index_length after trimming common suffix');
  
  $tag_list_lane1->[0]->expected_sequence('TAGCTTGTTGA');
  $tag_list_lane1->[1]->expected_sequence('TGCGATGTTAA');
  $tag_list_lane1->[2]->expected_sequence('GGCCAATGGGG');
  ($index_list, $tag_seq_list) = $create_lane->_process_tag_list($tag_list_lane1);
  is_deeply($create_lane->_check_tag_length($tag_seq_list),[qw(TAGCTTGT TGCGATGT GGCCAATG)], 'expected tag sequence length are the same as the index_length after trimming common suffix');
  lives_ok {
    $create_lane->generate();
  } q{no croak running generate()};

}

{

  $util->multiplexed_rta_pre_gerald();
  my $create_lane;
  lives_ok {
    $create_lane = npg_pipeline::analysis::create_lane_tag_file->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      runfolder_path => $runfolder_path,
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{no croak creating new object};

  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );
  $create_lane->run()->batch_id( 6713 );
  my $tag_list_lane3 = $create_lane->batch->lanes->[0]->tag_list();
  is (scalar @{$tag_list_lane3}, 2, 'lane 1 for this batch two tags');

  lives_ok {
    $create_lane->generate();
  } q{no croak running generate() for batch 6713};

}

1;
__END__
