# $Id: 25-analysis-create_psuedo_qseq_custom-pb_cal.t 12818 2011-03-16 12:53:22Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 8;
use Test::Exception;
use lib qw{t};
use t::util;
use t::useragent;
use DateTime;
use Test::MockObject;
use Cwd;

BEGIN {
  use_ok(q{npg_pipeline::analysis::create_psuedo_qseq_custom});
}


my $ua = t::useragent->new({ is_success => 1 });
my $util = t::util->new({
  useragent => $ua,
});
$util->catch_email();
my $conf_path = $util->conf_path();

my $curdir = getcwd();

$ENV{TEST_API_UTIL} = $util->apiutil();
$ENV{TEST_BIN} = $curdir . q{/t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();
$ENV{TEST_FS_RESOURCE} = q{nfs_12};
$ENV{NPG_WEBSERVICE_CACHE_DIR} = $curdir . q{/t/data};

sub set_staging_analysis_area {
  my ( $arg_refs, $multiplexed ) = @_;
  `rm -rf $arg_refs->{runfolder_path}`;
  `mkdir -p $arg_refs->{pb_cal_path}`;
  `mkdir $arg_refs->{config_path}`;
  if ( $multiplexed ) {
    `cp t/data/Recipes/Recipe_GA2-PEM_MP_2x76Cycle+8_v7.7.xml $arg_refs->{runfolder_path}/`;
  } else {
    `cp t/data/Recipes/Recipe_GA2_37Cycle_PE_v6.1.xml $arg_refs->{runfolder_path}/`;
  }
  `cp t/data/Recipes/TileLayout.xml $arg_refs->{config_path}/`;
  return 1;
}

sub psuedo_partial {
  my ( $arg_refs, $multiplexed ) = @_;
  set_staging_analysis_area( $arg_refs, $multiplexed );
  
  my %replacements = (
    2 => q{t},
    3 => 2,
  );

  my $sys_return;
  foreach my $tile (1..10) {
    $tile = sprintf q{%04d}, $tile;
    foreach my $lane ( 1..8 ) {
      if ( $multiplexed ) {
        # we know that PB_cal only produces read 1 and 2 through into the PB_cal directory
        # but that all three will be 'mislabelled' in BaseCalls
        foreach my $end ( 1..3 ) {
          if ( $end != 2 && $lane != 8) {
            my $fn = qq{s_${lane}_${end}_${tile}_qseq_custom.txt};
            $sys_return = qx{touch $arg_refs->{pb_cal_path}/$fn};
            if ( $CHILD_ERROR ) {
              croak $sys_return;
            }
          }
          my $bc_fn = qq{s_${lane}_${end}_${tile}_qseq.txt};
          $sys_return = qx{touch $arg_refs->{basecall_path}/$bc_fn};
          if ( $CHILD_ERROR ) {
            croak $sys_return;
          }
        }
      } else {
        if ( $lane != 8 ) {
          $sys_return = qx{touch $arg_refs->{pb_cal_path}/s_${lane}_${tile}_qseq_custom.txt};
          if ( $CHILD_ERROR ) {
            croak $sys_return;
          }
        }
        $sys_return = qx{touch $arg_refs->{basecall_path}/s_${lane}_${tile}_qseq.txt};
        if ( $CHILD_ERROR ) {
          croak $sys_return;
        }
      }
    }
  }

  return 1;
}


sub nothing_to_psuedo {
  my ( $arg_refs, $multiplexed ) = @_;
  set_staging_analysis_area( $arg_refs, $multiplexed );

  my %replacements = (
    2 => q{t},
    3 => 2,
  );

  my $sys_return;
  foreach my $tile (1..10) {
    $tile = sprintf q{%04d}, $tile;
    foreach my $lane ( 1..8 ) {
      if ( $multiplexed ) {
        foreach my $end ( 1..3 ) {
          my $fn = qq{s_${lane}_${end}_${tile}_qseq_custom.txt};
          $sys_return = qx{touch $arg_refs->{pb_cal_path}/$fn};
          if ( $CHILD_ERROR ) {
            croak $sys_return;
          }
          my $bc_fn = qq{s_${lane}_${end}_${tile}_qseq.txt};
          $sys_return = qx{touch $arg_refs->{basecall_path}/$bc_fn};
          if ( $CHILD_ERROR ) {
            croak $sys_return;
          }
        }
      } else {
        $sys_return = qx{touch $arg_refs->{pb_cal_path}/s_${lane}_${tile}_qseq_custom.txt};
        if ( $CHILD_ERROR ) {
          croak $sys_return;
        }
        $sys_return = qx{touch $arg_refs->{basecall_path}/s_${lane}_${tile}_qseq.txt};
        if ( $CHILD_ERROR ) {
          croak $sys_return;
        }
      }
    }
  }

  return 1;
}

my $runfolder_path = $util->analysis_runfolder_path();
my $bustard_home   = qq{$runfolder_path/Data/Intensities};
my $basecall_path  = qq{$bustard_home/BaseCalls};
my $pb_cal_path    = qq{$basecall_path/PB_cal};
my $config_path    = qq{$runfolder_path/Config};

my $paths = {
  runfolder_path => $runfolder_path,
  bustard_home => $bustard_home,
  basecall_path => $basecall_path,
  pb_cal_path => $pb_cal_path,
  config_path => $config_path,
};

{
  nothing_to_psuedo( $paths );

  my $object;
  lives_ok { $object = npg_pipeline::analysis::create_psuedo_qseq_custom->new({
    id_run => 1234,
    run_folder => q{123456_Il2_1234},
    runfolder_path => $runfolder_path,
    bustard_path => $basecall_path,
    basecall_path => $basecall_path,
    recalibrated_path => $pb_cal_path,
    pb_cal_path => $pb_cal_path,
    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
  }); } q{object creation ok};
  isa_ok($object, q{npg_pipeline::analysis::create_psuedo_qseq_custom}, q{$object});

  lives_ok {
    $object->run();
  } q{all files present - not multiplexed};

  psuedo_partial( $paths );

  lives_ok {
    $object->run();
  } q{need to symlink lane 8};

}

{

  my $object;
  lives_ok { $object = npg_pipeline::analysis::create_psuedo_qseq_custom->new({
    id_run => 1234,
    run_folder => q{123456_Il2_1234},
    runfolder_path => $runfolder_path,
    bustard_path => $basecall_path,
    basecall_path => $basecall_path,
    recalibrated_path => $pb_cal_path,
    pb_cal_path => $pb_cal_path,
#    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
  }); } q{object creation ok};

  nothing_to_psuedo( $paths, 1 );

  my $missing_files = {};

  my @qseq_files_in_basecalls = $object->_obtain_files( {
    directory  => $basecall_path,
    file_match => q{_qseq.txt},
  } );

  lives_ok {
    $object->run();
  } q{all files present - multiplexed};

  psuedo_partial( $paths, 1 );

  @qseq_files_in_basecalls = $object->_obtain_files( {
    directory  => $basecall_path,
    file_match => q{_qseq.txt},
  } );

  lives_ok {
    $object->run();
  } q{need to symlink lane 8 and all tag files};

}
qx{rm -f *qseq*txt};
1;