# $Id: 70-spidering.t 12818 2011-03-16 12:53:22Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 22;
use Test::Exception::LessClever;
use lib qw{t};
use t::util;
use File::Spec::Functions qw(catfile);
use Cwd qw(cwd);

my $repos = catfile(cwd, q[t/data/sequence/references]);

BEGIN {
  use_ok( q{npg_pipeline::spider::AllRunInfo} );
  use_ok( q{npg_common::request});
}

my $util = t::util->new();
my $conf_path = $util->conf_path();

#my $request = npg_common::request->new();
{
  throws_ok {
    my $spidering = npg_pipeline::spider::AllRunInfo->new();
  } qr{id_run[ ]not[ ]provided}, q{id_run not provided};
}
{
  my $spidering;
  lives_ok {
    $spidering = npg_pipeline::spider::AllRunInfo->new({
      id_run => 1234,
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{created spidering run info object ok with id_run};
  isa_ok( $spidering, q{npg_pipeline::spider::AllRunInfo}, q{$spidering} );
  lives_ok {
    $spidering = npg_pipeline::spider::AllRunInfo->new({
      name => q{IL1_1234},
    });
  } q{created spidering run info object ok with name};
  is( $spidering->id_run(), 1234, q{id_run obtained from name} );
  lives_ok {
    $spidering = npg_pipeline::spider::AllRunInfo->new({
      run_folder => q{20100615_IL1_1234},
      ref_repository => $repos,
      lanes => [ (1..8) ],
    });
  } q{created spidering run info object ok with run_folder};
  is( $spidering->id_run(), 1234, q{id_run obtained from run_folder} );

  ok( ! $spidering->is_object( {} ), q{A HashRef is not an object} );
  ok( $spidering->is_object( $spidering ), q{$spidering is an object} );

  lives_ok {
    $spidering->npg_api_util();
  } q{we get an util object};

  $spidering->useragent( $util->useragent() );
  $spidering->clear_npg_api_util(); # we want it rebuilt with the useragent object in it

  is( $spidering->npg_api_util()->useragent(), $util->useragent(), q{npg_api_util rebuilt ok} );

  # this test seems to fail on filesystem - died: Bizarre copy of HASH in sassign at /software/perl-5.8.8/lib/5.8.8/Carp/Heavy.pm line 45.
  # think it is ok for now, need to investigate
  lives_ok {
    $spidering->spider_sequencescape_batch( 6713 );
  } q{sequencescape batch with pools spiders ok};

  $spidering->_seen_that_already( {} );

  # using lives_ok has a problem here due to the bug in Test::Exception (see cpan Test::Exception::LessClever for more info)
  lives_ok {
    $spidering->spider_all();
  } q{all spiders ok};
#   eval {
#     $spidering->spider_all();
#   };
#   ok( ! $EVAL_ERROR, q{all spiders ok} );

}

# set cache dir environment variable as source of data

{
  my $spidering;
  lives_ok {
    $spidering = npg_pipeline::spider::AllRunInfo->new({
      run_folder => q{20100615_IL1_1234},
      ref_repository => $repos,
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{set ourselves a new spidering object};

  diag q[setting $ENV{] . npg_common::request->cache_dir_var_name() . q[} to t/data];

  $ENV{npg_common::request->cache_dir_var_name()} = q{t/data};


  # using lives_ok has a problem here due to the bug in Test::Exception (see cpan Test::Exception::LessClever for more info)
  lives_ok {
    $spidering->spider_all();
  } q[no croak running with $ENV{] . npg_common::request->cache_dir_var_name() . q[} set];
#  eval {
#    $spidering->spider_all();
#  };
#  ok( ! $EVAL_ERROR, q[no croak running with $ENV{] . npg_common::request->cache_dir_var_name() . q[} set]);

  $spidering = npg_pipeline::spider::AllRunInfo->new({
    id_run => 4846,
    ref_repository => $repos,
  });

  lives_ok {
    $spidering->spider_all();
  } q[no croak running with $ENV{] . npg_common::request->cache_dir_var_name() . q[} set for run 4846];
#  eval {
#    $spidering->spider_all();
#  };
#  ok( ! $EVAL_ERROR, q[no croak running with $ENV{] . npg_common::request->cache_dir_var_name() . q[} set for run 4846]);
}

# set store data in cache as retrieved
# if you are looking for inspiration, this is how this is usually going to run
#$util = t::util->new();
{
  my $spidering;
  lives_ok {
    $spidering = npg_pipeline::spider::AllRunInfo->new({
      run_folder => q{20100615_IL1_1234},
      ref_repository => $repos,
      save2cache => 1,
      useragent => $util->useragent(), # if you are looking at this test for inspiration, this only here for testing purposes
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{set ourselves a new spidering object};

  $util->create_analysis();

  diag q[setting $ENV{] . npg_common::request->cache_dir_var_name() . q[} to ] . $util->standard_analysis_bustard_path();

  $ENV{npg_common::request->cache_dir_var_name()} = $util->standard_analysis_bustard_path();

  lives_ok {
    $spidering->spider_all();
  } q[no croak running with $ENV{] . npg_common::request->cache_dir_var_name() . q[} and save2cache flag set];

}

{
  my $spidering;
  lives_ok {
    $spidering = npg_pipeline::spider::AllRunInfo->new({
      run_folder => q{20100615_IL1_1234},
      ref_repository => $repos,
      save2cache => 1,
      useragent => $util->useragent(), # if you are looking at this test for inspiration, this only here for testing purposes
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{set ourselves a new spidering object};

  lives_ok {
    $spidering->spider_sequencescape_batch( 6959 );
  } q{sequencescape batch with pools spiders ok};

}
1;
